@@ -52,8 +52,10 @@ class NumerousApp():
         self.setup_scenario()
 
     def setup_scenario(self):
+        self.nc.set_scenario_progress('initializing', ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, force=True)
 
         self.scenario, self.model_definition, self.files = self.nc.get_scenario()
+
         main_job = None
         for job in self.scenario.get('jobs', {}).values():
             if job.get('isMain', True):
@@ -62,10 +64,11 @@ class NumerousApp():
         if not main_job:
             raise KeyError('no main job found on scenario')
 
+        org_job_id = self.nc._job_id
+        main_job_id = main_job.get('id')
+        self.nc._job_id = main_job_id
         self.nc._run_settings = None
 
-        self.nc.set_scenario_progress('initializing', ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, force=True)
-
         # Prepare simulation setup
 
         self.start_time = self.nc.run_settings.start.timestamp()
@@ -73,6 +76,7 @@ class NumerousApp():
         self.appname = self.scenario['scenarioName']
         self.allow_hibernation = self.nc.params.get('allow_hibernation', 'False')
         self.logger.info(f'allow hibernation: {self.allow_hibernation}')
+        self.nc._job_id = org_job_id
 
     def loop(self):
 
