@@ -26,6 +26,7 @@ class Component:
         self._import = import_flag
         self.inputs = {}
         self.model = None
+        self.components = {}
 
     def _initialize(self, system):
         if not self._import:
@@ -40,6 +41,9 @@ class Component:
         _entrypoint = getattr(importlib.import_module(self._path.as_posix()), self._handle)
         self._entrypoint = _entrypoint
 
+    def _add_subcomponent(self, component):
+        self.components.update({component.name: component})
+
 class Project:
     def __init__(self, project: dict=None):
         self._project = project
@@ -69,12 +73,13 @@ class NumerousSystem:
         self.end_time = end_time
         self._initialized = False
         self.logger = logging.getLogger('NumerousSystem')
+        self._model_folder = model_folder
 
         # Update status - clear current data
         self.nc.set_scenario_progress('Environment Initializing',ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, clean=True)
 
         # Initialize other system variables
-        self.component_list, self.components = format_job_spec(self.scenario, model_folder)
+        self.component_list, self.components = self._format_job_spec(self.scenario)
 
         # Download needed files
         self._download_custom_files()
@@ -143,52 +148,78 @@ class NumerousSystem:
             if component_name in self.components:
                 self.components[component_name].inputs.update({".".join(subcomponents): value})
 
-def format_job_spec(scenario, model_folder_name):
+    def _format_job_spec(self, scenario):
 
-    simcomponents = scenario['simComponents']
-    component_list = []
-    components = {}
+        simcomponents = scenario['simComponents']
+        component_list = []
+        components = {}
 
-    for simcomponent in simcomponents:
+        for simcomponent in simcomponents:
+            if simcomponent.get('disabled', False) or simcomponent.get('isSubcomponent'):
+                continue
+            component = self._add_components_recursive(simcomponents, simcomponent)
+            components.update({simcomponent['name']: component})
+            component_list.append(component)
+
+        # Return list of components
+
+        return component_list, components
+
+    def _find_subcomponents(self, subcomps, simcomponents):
+        subcomponents = []
+        for subcomp in subcomps:
+            for component in simcomponents:
+                if component.get('uuid') == subcomp.get('uuid'):
+                    subcomponents.append(component)
+        return subcomponents
+
+    def _add_components_recursive(self, simcomponents, simcomponent, level=0):
+        component = self._add_component(simcomponent)
+        subcomps = simcomponent.get('subcomponents')
+        if subcomps:
+            subcomponents_list = self._find_subcomponents(subcomps, simcomponents)
+            for subcomponent in subcomponents_list:
+                subcomponent = self._add_components_recursive(simcomponents, subcomponent, level=level+1)
+                component._add_subcomponent(subcomponent)
+        return component
+
+
+    def _add_component(self, simcomponent):
         model_name = None
         model_file_name = None
         handle = None
+        has_model = False
 
-        if not simcomponent['disabled']:
-            # Get values for helper variables
-            item_class = simcomponent['item_class']
-            items = item_class.split(".")
-            component_name = simcomponent['name']
-            if item_class and len(items) < 3:
-                raise IndexError(f"item {component_name} must have class of format x.y.z")
 
-            if item_class:
-                model_name = items[0]
-                model_file_name = items[1]
-                handle = items[2]
+        # Get values for helper variables
+        item_class = simcomponent['item_class']
+        items = item_class.split(".")
+        component_name = simcomponent['name']
 
-            # Format constant values ('parameters' in frontend)
-            component_constants = {
-                d['id']: d['value']
-                for d in simcomponent['parameters']
-            } if simcomponent['parameters'] else {}
+        if item_class and len(items) == 3:
+            model_name = items[0]
+            model_file_name = items[1]
+            handle = items[2]
+            has_model = True
 
-            # Format parameters ('inputVariables' in frontend)
-            component_parameters = {
-                d['id']: f'{simcomponent["name"]}.{d["id"]}'
-                for d in simcomponent['inputVariables']
-            } if simcomponent['inputVariables'] else {}
+        # Format constant values ('parameters' in frontend)
+        component_constants = {
+            d['id']: d['value']
+            for d in simcomponent['parameters']
+        } if simcomponent['parameters'] else {}
 
-            # Make a complete dict with formatted specifications
+        # Format parameters ('inputVariables' in frontend)
+        component_parameters = {
+            d['id']: f'{simcomponent["name"]}.{d["id"]}'
+            for d in simcomponent['inputVariables']
+        } if simcomponent['inputVariables'] else {}
 
-            component = Component(name=component_name,
-                                  folder=f"{model_folder_name}/{model_name}",
-                                  path=f"{model_folder_name}.{model_name}.{model_file_name}", handle=handle,
-                                  constants=component_constants,
-                                  parameters=component_parameters, import_flag=bool(item_class) and model_folder_name)
-            component_list.append(component)
-            components.update({component_name: component})
+        # Make a complete dict with formatted specifications
 
-    # Return list of components
+        component = Component(name=component_name,
+                              folder=f"{self._model_folder}/{model_name}",
+                              path=f"{self._model_folder}.{model_name}.{model_file_name}", handle=handle,
+                              constants=component_constants,
+                              parameters=component_parameters, import_flag=has_model and self._model_folder)
 
-    return component_list, components
\ No newline at end of file
+        return component
